Module blaxel.models.integration_connection_spec
================================================

Classes
-------

`IntegrationConnectionSpec(config: blaxel.types.Unset | ForwardRef('IntegrationConnectionSpecConfig') = <blaxel.types.Unset object>, integration: blaxel.types.Unset | str = <blaxel.types.Unset object>, sandbox: blaxel.types.Unset | bool = <blaxel.types.Unset object>, secret: blaxel.types.Unset | ForwardRef('IntegrationConnectionSpecSecret') = <blaxel.types.Unset object>)`
:   Integration connection specification
    
    Attributes:
        config (Union[Unset, IntegrationConnectionSpecConfig]): Additional configuration for the integration
        integration (Union[Unset, str]): Integration type
        sandbox (Union[Unset, bool]): Sandbox mode
        secret (Union[Unset, IntegrationConnectionSpecSecret]): Integration secret
    
    Method generated by attrs for class IntegrationConnectionSpec.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `config`
    :

    `integration`
    :

    `sandbox`
    :

    `secret`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :